==> ejc-ztpcct-impl-3.0.0-20240725.075727-173-sources.jar: com/ejianc/design/bean/DesignOpinionInfoEntity.java <==
package com.ejianc.design.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计管理意见栏
 * 
 * @author generator
 * 
 */
 @TableName("ejc_design_opinion_info")
public class DesignOpinionInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="relative_chapter")
    private String relativeChapter; // 对应章节
    @TableField(value="original_content")
    private String originalContent; // 原文内容
    @TableField(value="edit_opinion")
    private String editOpinion; // 修改意见
    @TableField(value="reminder_content")
    private String reminderContent; // 建议项/必改项
    @TableField(value="propose_user_id")
    private Long proposeUserId; // 提出人
    @TableField(value="mobile")
    private String mobile; // 手机号
    @TableField(value="whether_accept")
    private String whetherAccept; // 是否采纳（Y：是，N：否）
    @TableField(value="abarbeitung_case")
    private String abarbeitungCase; // 整改情况
    @TableField(value="attachment")
    private Long attachment; // 附件
    @TableField(value="pid")
    private Long pid; // 父ID
    @TableField(value="propose_user_name")
    private String proposeUserName; // 提出人名称
    @TableField(value="reminder_content_id")
    private Integer reminderContentId; // 建议项/必改项(下拉)
    @TableField(value = "certification_conclusion_id")
    private Integer certificationConclusionId;//论证结论
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getRelativeChapter() {
        return relativeChapter;
    }

    public void setRelativeChapter(String relativeChapter) {
        this.relativeChapter = relativeChapter;
    }
    public String getEditOpinion() {
        return editOpinion;
    }

    public void setEditOpinion(String editOpinion) {
        this.editOpinion = editOpinion;
    }
    public String getReminderContent() {
        return reminderContent;
    }

    public void setReminderContent(String reminderContent) {
        this.reminderContent = reminderContent;
    }
    public Long getProposeUserId() {
        return proposeUserId;
    }

    public void setProposeUserId(Long proposeUserId) {
        this.proposeUserId = proposeUserId;
    }
    public String getProposeUserName() {
        return proposeUserName;
    }

    public void setProposeUserName(String proposeUserName) {
        this.proposeUserName = proposeUserName;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getWhetherAccept() {
        return whetherAccept;
    }

    public void setWhetherAccept(String whetherAccept) {
        this.whetherAccept = whetherAccept;
    }
    public String getAbarbeitungCase() {
        return abarbeitungCase;
    }

    public void setAbarbeitungCase(String abarbeitungCase) {
        this.abarbeitungCase = abarbeitungCase;
    }
    public Long getAttachment() {
        return attachment;
    }

    public void setAttachment(Long attachment) {
        this.attachment = attachment;
    }
    public Integer getReminderContentId() {
        return reminderContentId;
    }

    public void setReminderContentId(Integer reminderContentId) {
        this.reminderContentId = reminderContentId;
    }
    public Integer getCertificationConclusionId() {
        return certificationConclusionId;
    }

    public void setCertificationConclusionId(Integer certificationConclusionId) {
        this.certificationConclusionId = certificationConclusionId;
    }

    public String getOriginalContent() {
        return originalContent;
    }

    public void setOriginalContent(String originalContent) {
        this.originalContent = originalContent;
    }
}

==> ejc-ztpcct-impl-3.0.0-20241022.091131-184-sources.jar: com/ejianc/design/bean/DesignOpinionInfoEntity.java <==
package com.ejianc.design.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计管理意见栏
 * 
 * @author generator
 * 
 */
 @TableName("ejc_design_opinion_info")
public class DesignOpinionInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="relative_chapter")
    private String relativeChapter; // 对应章节
    @TableField(value="original_content")
    private String originalContent; // 原文内容
    @TableField(value="edit_opinion")
    private String editOpinion; // 修改意见
    @TableField(value="reminder_content")
    private String reminderContent; // 建议项/必改项
    @TableField(value="propose_user_id")
    private Long proposeUserId; // 提出人
    @TableField(value="mobile")
    private String mobile; // 手机号
    @TableField(value="whether_accept")
    private String whetherAccept; // 是否采纳（Y：是，N：否）
    @TableField(value="abarbeitung_case")
    private String abarbeitungCase; // 整改情况
    @TableField(value="attachment")
    private Long attachment; // 附件
    @TableField(value="pid")
    private Long pid; // 父ID
    @TableField(value="propose_user_name")
    private String proposeUserName; // 提出人名称
    @TableField(value="reminder_content_id")
    private Integer reminderContentId; // 建议项/必改项(下拉)
    @TableField(value = "certification_conclusion_id")
    private Integer certificationConclusionId;//论证结论
     @TableField(value = "close_flag")
    private Integer closeFlag;//是否关闭(1:是, 0:否)

    @TableField(value="file_code")
    private String fileCode; // 文件编码
    @TableField(value="file_name")
    private String fileName; // 文件名称
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getRelativeChapter() {
        return relativeChapter;
    }

    public void setRelativeChapter(String relativeChapter) {
        this.relativeChapter = relativeChapter;
    }
    public String getEditOpinion() {
        return editOpinion;
    }

    public void setEditOpinion(String editOpinion) {
        this.editOpinion = editOpinion;
    }
    public String getReminderContent() {
        return reminderContent;
    }

    public void setReminderContent(String reminderContent) {
        this.reminderContent = reminderContent;
    }
    public Long getProposeUserId() {
        return proposeUserId;
    }

    public void setProposeUserId(Long proposeUserId) {
        this.proposeUserId = proposeUserId;
    }
    public String getProposeUserName() {
        return proposeUserName;
    }

    public void setProposeUserName(String proposeUserName) {
        this.proposeUserName = proposeUserName;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getWhetherAccept() {
        return whetherAccept;
    }

    public void setWhetherAccept(String whetherAccept) {
        this.whetherAccept = whetherAccept;
    }
    public String getAbarbeitungCase() {
        return abarbeitungCase;
    }

    public void setAbarbeitungCase(String abarbeitungCase) {
        this.abarbeitungCase = abarbeitungCase;
    }
    public Long getAttachment() {
        return attachment;
    }

    public void setAttachment(Long attachment) {
        this.attachment = attachment;
    }
    public Integer getReminderContentId() {
        return reminderContentId;
    }

    public void setReminderContentId(Integer reminderContentId) {
        this.reminderContentId = reminderContentId;
    }
    public Integer getCertificationConclusionId() {
        return certificationConclusionId;
    }

    public void setCertificationConclusionId(Integer certificationConclusionId) {
        this.certificationConclusionId = certificationConclusionId;
    }

    public String getOriginalContent() {
        return originalContent;
    }

    public void setOriginalContent(String originalContent) {
        this.originalContent = originalContent;
    }

    public Integer getCloseFlag() {
        return closeFlag;
    }

    public void setCloseFlag(Integer closeFlag) {
        this.closeFlag = closeFlag;
    }

    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
}
